Computes the fit measures (chi-square, SRMR, RMSEA) for each level. The observed (auxiliary) correlation matrices of the levels are compared with the ones implied by the model.

# S4 method for class 'PlsMultilevelModel'
fit_measures(object, saturated = FALSE, mc.reps = 1e+06, ...)

Arguments

object

A PlsMultilevelModel object.

saturated

Logical; if TRUE, compute the saturated fit.

mc.reps

Integer; number of observations in the simulated data.

...

Currently unused.

Value

A list with the fit measures of each level (level.1 and level.2).