Returns the implied indicator correlation matrix for a fitted model.

implied_indicator_corr(object, saturated = FALSE, mc.reps = 1e+06, ...)

# S4 method for class 'PlsModel'
implied_indicator_corr(object, saturated = FALSE, mc.reps = 1e+06, ...)

Arguments

object

A fitted [PlsModel] object.

saturated

Logical; if `TRUE`, return the saturated implied matrix.

mc.reps

Integer; number of Monte Carlo resamples used for MC-PLSc.

...

Reserved for future extensions.

Value

A numeric matrix.

Details

For higher-order models, this is computed for the combined model returned by [combinedModel()].