mcpls_loglik: Loglikelihood of MC-PLS parameters

mcpls_loglikR Documentation

Loglikelihood of MC-PLS parameters

Description

Compute Loglikelihood statistics for an MC-PLS model.

Usage

mcpls_loglik(object, boot.R = 500, verbose = interactive(), ...)

## S4 method for signature 'PlsModel'
mcpls_loglik(object, boot.R = 500, verbose = interactive(), ...)

Arguments

object

A fitted [PlsModel] object, using MC-PLS.

boot.R

Integer; Number of bootstrap replicates.

verbose

Logical; Should a progressbar be displayed?

...

Reserved for future extensions.

Value

List with loglikelihood value, expected and observed auxiliary parameters, and variance covariance matrix of the expected auxiliary parameters.


plssem documentation built on Sept. 26, 2026, 5:06 p.m.