parameter_estimates.plssem: Parameter estimates for 'plssem' objects

View source: R/generics.R

parameter_estimates.plssemR Documentation

Parameter estimates for 'plssem' objects

Description

Parameter estimates for 'plssem' objects

Usage

## S3 method for class 'plssem'
parameter_estimates(object, colon.pi = TRUE, label.renamed.prod = FALSE, ...)

Arguments

object

An object of class 'plssem'.

colon.pi

Logical; whether to replace labels for interaction terms with colon notation.

label.renamed.prod

Logical; whether renamed product labels should be retained when colon expansion occurs.

...

Additional arguments (not used).

Value

A parameter table (data frame) describing the fitted model.


plssem documentation built on March 23, 2026, 5:08 p.m.