| pls_implied_indicator_corr | R Documentation |
Returns the implied indicator correlation matrix for a fitted model.
pls_implied_indicator_corr(object, saturated = FALSE, mc.reps = 1e+06, ...)
## S4 method for signature 'PlsModel'
pls_implied_indicator_corr(object, saturated = FALSE, mc.reps = 1e+06, ...)
object |
A fitted [PlsModel] object. |
saturated |
Logical; if 'TRUE', return the saturated implied matrix. |
mc.reps |
Integer; number of Monte Carlo resamples used for MC-PLSc. |
... |
Reserved for future extensions. |
For higher-order models, this is computed for the combined model returned by [combinedModel()].
A numeric matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.