show-PlsModel-method: Show a 'PlsModel' object

show,PlsModel-methodR Documentation

Show a PlsModel object

Description

Called automatically when an object is printed at the prompt. Displays the package version, iteration count, and the parameter table.

Usage

## S4 method for signature 'PlsModel'
show(object)

Arguments

object

A PlsModel object.

Value

object, invisibly.


plssem documentation built on Sept. 26, 2026, 5:06 p.m.