Returns the implied indicator correlation matrix for a fitted model.
implied_indicator_corr(object, saturated = FALSE, mc.reps = 1e+06, ...)
# S4 method for class 'PlsModel'
implied_indicator_corr(object, saturated = FALSE, mc.reps = 1e+06, ...)A numeric matrix.
For higher-order models, this is computed for the combined model returned by [combinedModel()].