Compute Loglikelihood statistics for an MC-PLS model.
mcpls_loglik(object, boot.R = 500, verbose = interactive(), ...)
# S4 method for class 'PlsModel'
mcpls_loglik(object, boot.R = 500, verbose = interactive(), ...)List with loglikelihood value, expected and observed auxiliary parameters, and variance covariance matrix of the expected auxiliary parameters.