| mcpls_loglik | R Documentation |
Compute Loglikelihood statistics for an MC-PLS model.
mcpls_loglik(object, boot.R = 500, verbose = interactive(), ...)
## S4 method for signature 'PlsModel'
mcpls_loglik(object, boot.R = 500, verbose = interactive(), ...)
object |
A fitted [PlsModel] object, using MC-PLS. |
boot.R |
Integer; Number of bootstrap replicates. |
verbose |
Logical; Should a progressbar be displayed? |
... |
Reserved for future extensions. |
List with loglikelihood value, expected and observed auxiliary parameters, and variance covariance matrix of the expected auxiliary parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.