| parameter_estimates.plssem | R Documentation |
Parameter estimates for 'plssem' objects
## S3 method for class 'plssem'
parameter_estimates(object, colon.pi = TRUE, label.renamed.prod = FALSE, ...)
object |
An object of class 'plssem'. |
colon.pi |
Logical; whether to replace labels for interaction terms with colon notation. |
label.renamed.prod |
Logical; whether renamed product labels should be retained when colon expansion occurs. |
... |
Additional arguments (not used). |
A parameter table (data frame) describing the fitted model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.