| pls | R Documentation |
pls() estimates Partial Least Squares Structural Equation Models (PLS-SEM)
and their consistent (PLSc) variants. The function accepts lavaan-style
syntax, handles ordered indicators through polychoric correlations and probit
factor scores, and supports multilevel specifications expressed with
lme4-style random effects terms inside the structural model.
pls(
syntax,
data,
standardize = TRUE,
consistent = TRUE,
bootstrap = FALSE,
ordered = NULL,
missing = c("listwise", "mean", "kNN"),
knn.k = 5,
mcpls = NULL,
mc.fast.lmer = mcpls,
probit = NULL,
tolerance = 1e-05,
max.iter.0_5 = 500L,
boot.ncores = 1L,
boot.ncpus = NULL,
boot.parallel = c("no", "multicore", "multisession", "snow"),
boot.R = 500L,
boot.iseed = NULL,
sample = NULL,
mc.min.iter = 50L,
mc.max.iter = 1000L,
mc.reps = 20000L,
mc.fixed.seed = FALSE,
mc.polyak.juditsky = TRUE,
mc.pj.extrapolate = TRUE,
mc.tol = if (mc.polyak.juditsky) 1e-04 else 0.001,
mc.delta.se = TRUE,
mc.delta.jacobian.k = max(floor(boot.R/100L), 1),
mc.fn.args = list(),
mc.rescov = c("auto", "reduced", "full"),
mc.diag.secant = FALSE,
mc.small.sample = FALSE,
mc.small.sample.max.k = 100L,
mc.small.sample.point.estimate = c("median", "mean"),
verbose = interactive(),
boot.optimize = TRUE,
boot.drop.inadmissible = FALSE,
mc.boot.control = list(min.iter = mc.min.iter, max.iter = mc.max.iter, mc.reps =
floor(0.5 * mc.reps), tol = mc.tol, polyak.juditsky = mc.polyak.juditsky,
pj.extrapolate = FALSE, verbose = FALSE, fixed.seed = TRUE, reuse.p.start = TRUE),
reliabilities = NULL,
default.path.estimator = c("ols", "gls"),
...
)
syntax |
Character string with |
data |
A |
standardize |
Logical; if |
consistent |
Logical; |
bootstrap |
Logical; if |
ordered |
Optional character vector naming manifest indicators that should be treated as ordered when computing polychoric correlations. |
missing |
Character string specifying how to handle missing indicator data.
|
knn.k |
Integer specifying the number of neighbors ( |
mcpls |
Should the model be estimated using the Monte-Carlo Consistent Partial Least Squares (MC-PLSc) algorithm? |
mc.fast.lmer |
Should a faster (biased) GLS based estimator of the Mixed-Effects model be used in conjunction with the MC-PLS algorithm? |
probit |
Logical; overrides the automatic choice of probit factor scores that is based on whether ordered indicators are present. |
tolerance |
Numeric; Convergence criteria/tolerance. |
max.iter.0_5 |
Maximum number of PLS iterations performed when estimating the measurement and structural models. |
boot.ncores |
Integer: number of workers to be used for parallel bootstrapping.
Parallel bootstrapping is enabled when |
boot.ncpus |
Deprecated alias for |
boot.parallel |
The type of parallel operation to be used (if any). The
default is |
boot.R |
Integer giving the number of bootstrap resamples drawn when
|
boot.iseed |
An integer to set the bootstrap seed. Or |
sample |
DEPRECATED. Integer giving the number of bootstrap resamples drawn when
|
mc.min.iter |
Minimum number of iterations in MC-PLS algorithm. |
mc.max.iter |
Maximum number of iterations in MC-PLS algorithm. |
mc.reps |
Monte-Carlo sample size in MC-PLS algorithm. |
mc.fixed.seed |
Should a fixed seed be used in the MC-PLS algorithm? Setting a fixed seed will likely yield less accurate estimates, but can substantially improve the stability and computational efficiency of the algorithm. |
mc.polyak.juditsky |
Should the polyak.juditsky running average method be applied in the MC-PLS algorithm? |
mc.pj.extrapolate |
Logical; if |
mc.tol |
Tolerance in MC-PLS algorithm. |
mc.delta.se |
Should delta-method standard errors be computed for MC-PLS estimates? |
mc.delta.jacobian.k |
Integer number of Monte-Carlo Jacobians to average when computing delta-method standard errors. Defaults to one per 100 bootstrap resamples, with a minimum of 1. |
mc.fn.args |
Additional arguments to MC-PLS algorithm, mainly for controlling the step size. |
mc.rescov |
How residual covariances are treated in MC-PLS. One of
|
mc.diag.secant |
Logical; if |
mc.small.sample |
Logical; if |
mc.small.sample.max.k |
Maximum number of simulated samples to average
when |
mc.small.sample.point.estimate |
Which point estimate of the simulated
auxiliary parameters the root equation matches to the observed ones, when
The median commutes with the (monotone) binding function where the mean
does not, so median-matching targets a median-unbiased estimator. This
removes the finite-sample bias. which can be introduced by the curvature
size models, and when the indicators are uninformative (small loadings,
few categories, strongly assymetric thresholds). It makes the estimating
function somewhat noisier for a given number of simulated samples.
Ignored when |
verbose |
Should verbose output be printed? |
boot.optimize |
Logical; if |
boot.drop.inadmissible |
Logical; if |
mc.boot.control |
List of control parameters passed to the MC-PLS algorithm
inside each bootstrap replicate when |
reliabilities |
Optional named numeric vector of user-supplied reliabilities used for the PLSc consistency correction. |
default.path.estimator |
Character string selecting the estimator used for
the structural (path) model when the model does not require Generalized Least
Squares (GLS). The default |
... |
Internal arguments. For advanced users only. |
A Plssem object containing the estimated parameters, fit measures,
factor scores, and any bootstrap results. Methods such as summary(),
coef(), and parameter_estimates() can be applied to inspect the fit.
summary,
show
library(plssem)
library(modsem)
tpb <- '
ATT =~ att1 + att2 + att3 + att4 + att5
SN =~ sn1 + sn2
PBC =~ pbc1 + pbc2 + pbc3
INT =~ int1 + int2 + int3
BEH =~ b1 + b2
INT ~ ATT + SN + PBC
BEH ~ INT + PBC
'
fit <- pls(tpb, TPB, bootstrap = TRUE)
summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.