Extract important information from a fitted PlsModel. The interface is
modelled after lavaan::lavInspect(): a single what argument
selects which piece of information to return.
pls_inspect(object, what = "estimates", ...)
# S4 method for class 'PlsModel'
pls_inspect(object, what = "estimates", ...)A fitted PlsModel object.
A single string selecting what to extract (case-insensitive);
defaults to "estimates". Several values accept aliases, given in
parentheses. One of:
"estimates" (aliases "est", "x",
"matrices")A list of the estimated model matrices in
lavaan-style representation (lambda, wmat, theta,
psi, C, gamma).
"lambda", "wmat", "theta", "psi",
"C", "gamma"The corresponding single matrix from the
"estimates" list.
"coef" (alias "coefficients")The model coefficients.
"par" (alias "partable")The parameter table.
"fit"Fit measures.
"mcpls.history" (alias "history")The history of the MC-PLS estimates.
"chisq"The model chi-square statistic.
"chisq.df" (alias "df")The chi-square degrees of freedom.
"srmr"The standardized root mean square residual.
"rmsea"The root mean square error of approximation.
"se"The standard errors of the estimates.
"vcov"The variance-covariance matrix of the estimates.
"boot"The bootstrap results.
"info"A list with the number of observations (nobs),
the number of latent variables (nlv), the number of observed
variables (nov), and the estimation modes ("A"/"B")
for each latent variable.
"status"A list with the number of iterations, whether
the algorithm converged, and whether the solution is
admissible.
"qualities"The construct qualities (\(Q^2\)).
"reliabilities" (alias "rel")The construct reliabilities.
"cov.lv"The model-implied covariance matrix of the latent variables.
"cov.ov"The model-implied covariance matrix of the observed variables.
"cov.all"The joint model-implied covariance matrix of the observed and latent variables.
"r2.lv", "r2.ov", "r2.all"The model-implied \(R^2\) for the latent variables, the observed variables, or both.
"data"The (standardized) data matrix used for estimation.
Currently ignored.
The requested information; the type depends on what (see above).
if (FALSE) { # \dontrun{
fit <- pls(model, data = data)
pls_inspect(fit, "info")
pls_inspect(fit, "cov.lv")
} # }