Called automatically when an object is printed at the prompt. Displays the package version, iteration count, and the parameter table.

# S4 method for class 'PlsModel'
show(object)

Arguments

object

A PlsModel object.

Value

object, invisibly.