Transform parameter estimates from a fitted PLS-SEM model to observed- and
latent-variable scales. Variables not selected through unstandardized
remain on their standardized scales.
unstandardized_estimates(
model,
unstandardized = "all",
se = c("delta", "none"),
scale.uncertainty = FALSE,
eps = 1e-04,
zero.tol = 1e-10,
rm.tmp.ov = TRUE,
clean.tmp.ind = TRUE,
clean.tmp.mimic = TRUE
)
# S4 method for class 'PlsModel'
unstandardized_estimates(
model,
unstandardized = "all",
se = c("delta", "none"),
scale.uncertainty = FALSE,
eps = 1e-04,
zero.tol = 1e-10,
rm.tmp.ov = TRUE,
clean.tmp.ind = TRUE,
clean.tmp.mimic = TRUE
)A fitted PlsModel object.
Character vector naming variables to unstandardize, or
one of "all", "ov", or "lv".
Character string selecting delta-method standard errors
("delta") or no standard errors ("none").
Should scale uncertainty be included?
defaults to FALSE.
Positive numeric finite-difference step used for the delta-method Jacobian.
Non-negative numeric tolerance below which standard errors are returned as missing.
Logical; whether rows involving temporary observed variables should be removed from the returned parameter table.
Logical; whether rows involving temporary indicators should be cleaned from the returned parameter table.
Logical; whether rows involving temporary mimic indicators should be cleaned from the returned parameter table.
A PlsSemParTable containing transformed estimates and (when
requested) delta-method standard errors. The transformed covariance matrix
is stored in the "vcov" attribute.
tpb <- '
# Outer Model (Based on Hagger et al., 2007)
ATT <~ att1 + att2 + att3 + att4 + att5
SN =~ sn1 + sn2
PBC =~ pbc1 + pbc2 + pbc3
INT =~ int1 + int2 + int3
BEH <~ b1 + b2
# Inner Model (Based on Steinmetz et al., 2011)
INT ~ ATT + SN + PBC
BEH ~ INT + PBC + INT:PBC
'
fit <- pls(tpb, modsem::TPB, bootstrap = TRUE, boot.R = 50)
unstandardized_estimates(fit)
#> lhs op rhs label est se z pvalue ci.lower ci.upper
#> 1 ATT <~ att1 1.000 NA NA NA NA NA
#> 2 ATT <~ att2 0.918 0.669 1.371 0.170 -0.394 2.229
#> 3 ATT <~ att3 1.085 0.621 1.746 0.081 -0.133 2.302
#> 4 ATT <~ att4 0.788 0.481 1.638 0.101 -0.155 1.731
#> 5 ATT <~ att5 1.272 0.706 1.803 0.071 -0.111 2.655
#> 6 SN =~ sn1 1.000 NA NA NA NA NA
#> 7 SN =~ sn2 0.921 0.020 45.610 0.000 0.881 0.961
#> 8 PBC =~ pbc1 1.000 NA NA NA NA NA
#> 9 PBC =~ pbc2 0.933 0.017 55.130 0.000 0.900 0.966
#> 10 PBC =~ pbc3 0.801 0.017 46.240 0.000 0.767 0.835
#> 11 INT =~ int1 1.000 NA NA NA NA NA
#> 12 INT =~ int2 0.936 0.016 57.181 0.000 0.904 0.968
#> 13 INT =~ int3 0.809 0.018 45.259 0.000 0.774 0.844
#> 14 BEH <~ b1 1.000 NA NA NA NA NA
#> 15 BEH <~ b2 1.476 0.399 3.698 0.000 0.694 2.259
#> 16 INT ~ ATT 0.045 0.017 2.703 0.007 0.012 0.077
#> 17 INT ~ SN 0.185 0.025 7.255 0.000 0.135 0.235
#> 18 INT ~ PBC 0.224 0.030 7.512 0.000 0.166 0.283
#> 19 BEH ~ PBC 0.558 0.101 5.549 0.000 0.361 0.755
#> 20 BEH ~ INT 0.471 0.098 4.787 0.000 0.278 0.665
#> 21 BEH ~ INT:PBC 0.506 0.085 5.951 0.000 0.339 0.672
#> 22 ATT ~~ ATT 19.621 14.479 1.355 0.175 -8.757 47.999
#> 23 ATT ~~ SN 2.682 0.997 2.691 0.007 0.729 4.635
#> 24 ATT ~~ PBC 2.921 1.089 2.681 0.007 0.786 5.056
#> 25 ATT ~~ INT:PBC 0.360 0.228 1.574 0.116 -0.088 0.807
#> 26 SN ~~ SN 0.953 0.021 45.224 0.000 0.912 0.994
#> 27 SN ~~ PBC 0.662 0.014 48.585 0.000 0.635 0.689
#> 28 SN ~~ INT:PBC 0.054 0.041 1.330 0.184 -0.026 0.134
#> 29 PBC ~~ PBC 0.948 0.022 43.846 0.000 0.906 0.990
#> 30 PBC ~~ INT:PBC 0.084 0.050 1.672 0.095 -0.015 0.183
#> 31 INT ~~ INT 0.484 0.014 34.573 0.000 0.456 0.511
#> 32 BEH ~~ BEH 3.142 1.014 3.098 0.002 1.154 5.129
#> 33 INT:PBC ~~ INT:PBC 0.957 0.073 13.099 0.000 0.813 1.100
#> 34 att1 ~~ att1 1.166 NA NA NA NA NA
#> 35 att1 ~~ att2 0.878 0.007 133.745 0.000 0.865 0.891
#> 36 att1 ~~ att3 0.788 0.007 111.950 0.000 0.774 0.802
#> 37 att1 ~~ att4 0.693 0.008 82.777 0.000 0.676 0.709
#> 38 att1 ~~ att5 0.885 0.007 131.571 0.000 0.872 0.898
#> 39 att2 ~~ att2 0.920 NA NA NA NA NA
#> 40 att2 ~~ att3 0.692 0.007 101.308 0.000 0.678 0.705
#> 41 att2 ~~ att4 0.609 0.006 99.906 0.000 0.597 0.621
#> 42 att2 ~~ att5 0.778 0.007 118.603 0.000 0.765 0.790
#> 43 att3 ~~ att3 0.781 NA NA NA NA NA
#> 44 att3 ~~ att4 0.547 0.007 78.426 0.000 0.534 0.561
#> 45 att3 ~~ att5 0.698 0.008 89.632 0.000 0.682 0.713
#> 46 att4 ~~ att4 0.645 NA NA NA NA NA
#> 47 att4 ~~ att5 0.616 0.007 88.164 0.000 0.602 0.629
#> 48 att5 ~~ att5 0.944 NA NA NA NA NA
#> 49 sn1 ~~ sn1 0.213 0.021 10.111 0.000 0.172 0.254
#> 50 sn2 ~~ sn2 0.128 0.020 6.420 0.000 0.089 0.167
#> 51 pbc1 ~~ pbc1 0.159 0.022 7.366 0.000 0.117 0.202
#> 52 pbc2 ~~ pbc2 0.136 0.020 6.902 0.000 0.097 0.174
#> 53 pbc3 ~~ pbc3 0.164 0.017 9.731 0.000 0.131 0.197
#> 54 int1 ~~ int1 0.171 0.018 9.659 0.000 0.136 0.206
#> 55 int2 ~~ int2 0.140 0.015 9.511 0.000 0.111 0.169
#> 56 int3 ~~ int3 0.174 0.015 11.905 0.000 0.146 0.203
#> 57 b1 ~~ b1 0.815 NA NA NA NA NA
#> 58 b1 ~~ b2 0.605 0.007 82.140 0.000 0.590 0.619
#> 59 b2 ~~ b2 0.716 NA NA NA NA NA