Transform parameter estimates from a fitted PLS-SEM model to observed- and
latent-variable scales. Variables not selected through unstandardized
remain on their standardized scales.
unstandardized_estimates(
model,
unstandardized = "all",
se = c("delta", "none"),
scale.uncertainty = FALSE,
eps = 1e-04,
zero.tol = 1e-10,
rm.tmp.ov = TRUE,
clean.tmp.ind = TRUE,
clean.tmp.mimic = TRUE
)
# S4 method for class 'PlsModel'
unstandardized_estimates(
model,
unstandardized = "all",
se = c("delta", "none"),
scale.uncertainty = FALSE,
eps = 1e-04,
zero.tol = 1e-10,
rm.tmp.ov = TRUE,
clean.tmp.ind = TRUE,
clean.tmp.mimic = TRUE
)A fitted PlsModel object.
Character vector naming variables to unstandardize, or
one of "all", "ov", or "lv".
Character string selecting delta-method standard errors
("delta") or no standard errors ("none").
Should scale uncertainty be included?
defaults to FALSE.
Positive numeric finite-difference step used for the delta-method Jacobian.
Non-negative numeric tolerance below which standard errors are returned as missing.
Logical; whether rows involving temporary observed variables should be removed from the returned parameter table.
Logical; whether rows involving temporary indicators should be cleaned from the returned parameter table.
Logical; whether rows involving temporary mimic indicators should be cleaned from the returned parameter table.
A PlsSemParTable containing transformed estimates and (when
requested) delta-method standard errors. The transformed covariance matrix
is stored in the "vcov" attribute.
tpb <- '
# Outer Model (Based on Hagger et al., 2007)
ATT <~ att1 + att2 + att3 + att4 + att5
SN =~ sn1 + sn2
PBC =~ pbc1 + pbc2 + pbc3
INT =~ int1 + int2 + int3
BEH <~ b1 + b2
# Inner Model (Based on Steinmetz et al., 2011)
INT ~ ATT + SN + PBC
BEH ~ INT + PBC + INT:PBC
'
fit <- pls(tpb, modsem::TPB, bootstrap = TRUE, boot.R = 50)
unstandardized_estimates(fit)
#> lhs op rhs label est se z pvalue ci.lower ci.upper
#> 1 ATT <~ att1 1.000 NA NA NA NA NA
#> 2 ATT <~ att2 0.918 0.612 1.499 0.134 -0.282 2.117
#> 3 ATT <~ att3 1.085 0.631 1.718 0.086 -0.152 2.322
#> 4 ATT <~ att4 0.788 0.469 1.679 0.093 -0.132 1.708
#> 5 ATT <~ att5 1.272 0.481 2.644 0.008 0.329 2.215
#> 6 SN =~ sn1 1.000 NA NA NA NA NA
#> 7 SN =~ sn2 0.921 0.022 41.408 0.000 0.877 0.965
#> 8 PBC =~ pbc1 1.000 NA NA NA NA NA
#> 9 PBC =~ pbc2 0.933 0.022 41.669 0.000 0.889 0.977
#> 10 PBC =~ pbc3 0.801 0.021 37.844 0.000 0.759 0.842
#> 11 INT =~ int1 1.000 NA NA NA NA NA
#> 12 INT =~ int2 0.936 0.024 39.307 0.000 0.890 0.983
#> 13 INT =~ int3 0.809 0.023 35.896 0.000 0.765 0.854
#> 14 BEH <~ b1 1.000 NA NA NA NA NA
#> 15 BEH <~ b2 1.476 0.416 3.550 0.000 0.661 2.291
#> 16 INT ~ ATT 0.045 0.013 3.370 0.001 0.019 0.071
#> 17 INT ~ SN 0.185 0.026 7.058 0.000 0.133 0.236
#> 18 INT ~ PBC 0.224 0.023 9.657 0.000 0.179 0.270
#> 19 BEH ~ PBC 0.558 0.088 6.374 0.000 0.386 0.729
#> 20 BEH ~ INT 0.471 0.112 4.193 0.000 0.251 0.692
#> 21 BEH ~ INT:PBC 0.506 0.092 5.503 0.000 0.326 0.686
#> 22 ATT ~~ ATT 19.621 11.198 1.752 0.080 -2.327 41.569
#> 23 ATT ~~ SN 2.682 0.770 3.483 0.000 1.173 4.191
#> 24 ATT ~~ PBC 2.921 0.830 3.518 0.000 1.294 4.548
#> 25 ATT ~~ INT:PBC 0.360 0.212 1.693 0.090 -0.057 0.776
#> 26 SN ~~ SN 0.953 0.039 24.261 0.000 0.876 1.030
#> 27 SN ~~ PBC 0.662 0.030 22.069 0.000 0.603 0.721
#> 28 SN ~~ INT:PBC 0.054 0.039 1.404 0.160 -0.021 0.130
#> 29 PBC ~~ PBC 0.948 0.043 22.112 0.000 0.864 1.032
#> 30 PBC ~~ INT:PBC 0.084 0.046 1.830 0.067 -0.006 0.174
#> 31 INT ~~ INT 0.484 0.025 19.364 0.000 0.435 0.533
#> 32 BEH ~~ BEH 3.142 1.054 2.981 0.003 1.076 5.207
#> 33 INT:PBC ~~ INT:PBC 0.957 0.100 9.541 0.000 0.760 1.153
#> 34 att1 ~~ att1 1.166 NA NA NA NA NA
#> 35 att1 ~~ att2 0.878 0.006 143.788 0.000 0.866 0.890
#> 36 att1 ~~ att3 0.788 0.007 119.399 0.000 0.775 0.801
#> 37 att1 ~~ att4 0.693 0.007 101.539 0.000 0.679 0.706
#> 38 att1 ~~ att5 0.885 0.007 121.286 0.000 0.870 0.899
#> 39 att2 ~~ att2 0.920 NA NA NA NA NA
#> 40 att2 ~~ att3 0.692 0.007 104.521 0.000 0.679 0.705
#> 41 att2 ~~ att4 0.609 0.007 85.831 0.000 0.595 0.623
#> 42 att2 ~~ att5 0.778 0.006 121.014 0.000 0.765 0.790
#> 43 att3 ~~ att3 0.781 NA NA NA NA NA
#> 44 att3 ~~ att4 0.547 0.006 87.246 0.000 0.535 0.560
#> 45 att3 ~~ att5 0.698 0.007 105.895 0.000 0.685 0.711
#> 46 att4 ~~ att4 0.645 NA NA NA NA NA
#> 47 att4 ~~ att5 0.616 0.006 94.742 0.000 0.603 0.629
#> 48 att5 ~~ att5 0.944 NA NA NA NA NA
#> 49 sn1 ~~ sn1 0.213 0.025 8.374 0.000 0.163 0.263
#> 50 sn2 ~~ sn2 0.128 0.020 6.439 0.000 0.089 0.167
#> 51 pbc1 ~~ pbc1 0.159 0.028 5.733 0.000 0.105 0.214
#> 52 pbc2 ~~ pbc2 0.136 0.023 5.922 0.000 0.091 0.181
#> 53 pbc3 ~~ pbc3 0.164 0.019 8.868 0.000 0.128 0.201
#> 54 int1 ~~ int1 0.171 0.026 6.615 0.000 0.120 0.222
#> 55 int2 ~~ int2 0.140 0.018 7.893 0.000 0.105 0.174
#> 56 int3 ~~ int3 0.174 0.015 11.633 0.000 0.145 0.204
#> 57 b1 ~~ b1 0.815 NA NA NA NA NA
#> 58 b1 ~~ b2 0.605 0.008 80.524 0.000 0.590 0.619
#> 59 b2 ~~ b2 0.716 NA NA NA NA NA