Transform parameter estimates from a fitted PLS-SEM model to observed- and
latent-variable scales. Variables not selected through unstandardized
remain on their standardized scales.
unstandardized_estimates(
model,
unstandardized = "all",
se = c("delta", "none"),
scale.uncertainty = FALSE,
eps = 1e-04,
zero.tol = 1e-10,
rm.tmp.ov = TRUE,
clean.tmp.ind = TRUE,
clean.tmp.mimic = TRUE
)
# S4 method for class 'PlsModel'
unstandardized_estimates(
model,
unstandardized = "all",
se = c("delta", "none"),
scale.uncertainty = FALSE,
eps = 1e-04,
zero.tol = 1e-10,
rm.tmp.ov = TRUE,
clean.tmp.ind = TRUE,
clean.tmp.mimic = TRUE
)A fitted PlsModel object.
Character vector naming variables to unstandardize, or
one of "all", "ov", or "lv".
Character string selecting delta-method standard errors
("delta") or no standard errors ("none").
Should scale uncertainty be included?
defaults to FALSE.
Positive numeric finite-difference step used for the delta-method Jacobian.
Non-negative numeric tolerance below which standard errors are returned as missing.
Logical; whether rows involving temporary observed variables should be removed from the returned parameter table.
Logical; whether rows involving temporary indicators should be cleaned from the returned parameter table.
Logical; whether rows involving temporary mimic indicators should be cleaned from the returned parameter table.
A PlsSemParTable containing transformed estimates and (when
requested) delta-method standard errors. The transformed covariance matrix
is stored in the "vcov" attribute.
tpb <- '
# Outer Model (Based on Hagger et al., 2007)
ATT <~ att1 + att2 + att3 + att4 + att5
SN =~ sn1 + sn2
PBC =~ pbc1 + pbc2 + pbc3
INT =~ int1 + int2 + int3
BEH <~ b1 + b2
# Inner Model (Based on Steinmetz et al., 2011)
INT ~ ATT + SN + PBC
BEH ~ INT + PBC + INT:PBC
'
fit <- pls(tpb, modsem::TPB, bootstrap = TRUE, boot.R = 50)
unstandardized_estimates(fit)
#> lhs op rhs est se z pvalue ci.lower ci.upper
#> 1 ATT <~ att1 1.000 NA NA NA NA NA
#> 2 ATT <~ att2 0.918 0.645 1.424 0.155 -0.346 2.181
#> 3 ATT <~ att3 1.085 0.619 1.751 0.080 -0.129 2.298
#> 4 ATT <~ att4 0.788 0.562 1.402 0.161 -0.314 1.890
#> 5 ATT <~ att5 1.272 0.741 1.716 0.086 -0.181 2.725
#> 6 SN =~ sn1 1.000 NA NA NA NA NA
#> 7 SN =~ sn2 0.921 0.026 36.057 0.000 0.871 0.971
#> 8 PBC =~ pbc1 1.000 NA NA NA NA NA
#> 9 PBC =~ pbc2 0.933 0.020 47.700 0.000 0.895 0.971
#> 10 PBC =~ pbc3 0.801 0.015 52.875 0.000 0.771 0.831
#> 11 INT =~ int1 1.000 NA NA NA NA NA
#> 12 INT =~ int2 0.936 0.017 54.372 0.000 0.903 0.970
#> 13 INT =~ int3 0.809 0.018 46.241 0.000 0.775 0.844
#> 14 BEH <~ b1 1.000 NA NA NA NA NA
#> 15 BEH <~ b2 1.476 0.420 3.515 0.000 0.653 2.299
#> 16 INT ~ ATT 0.045 0.018 2.498 0.012 0.010 0.080
#> 17 INT ~ SN 0.185 0.023 7.949 0.000 0.139 0.230
#> 18 INT ~ PBC 0.224 0.023 9.953 0.000 0.180 0.268
#> 19 BEH ~ PBC 0.558 0.097 5.758 0.000 0.368 0.748
#> 20 BEH ~ INT 0.471 0.097 4.865 0.000 0.282 0.661
#> 21 BEH ~ INT:PBC 0.506 0.089 5.706 0.000 0.332 0.680
#> 22 ATT ~~ ATT 19.621 15.135 1.296 0.195 -10.043 49.285
#> 23 ATT ~~ SN 2.682 1.054 2.544 0.011 0.616 4.748
#> 24 ATT ~~ PBC 2.921 1.129 2.586 0.010 0.707 5.134
#> 25 ATT ~~ INT:PBC 0.360 0.213 1.684 0.092 -0.059 0.778
#> 26 SN ~~ SN 0.953 0.043 22.410 0.000 0.870 1.037
#> 27 SN ~~ PBC 0.662 0.033 20.225 0.000 0.598 0.726
#> 28 SN ~~ INT:PBC 0.054 0.044 1.234 0.217 -0.032 0.140
#> 29 PBC ~~ PBC 0.948 0.038 24.992 0.000 0.874 1.022
#> 30 PBC ~~ INT:PBC 0.084 0.057 1.482 0.138 -0.027 0.196
#> 31 INT ~~ INT 0.484 0.017 28.998 0.000 0.451 0.516
#> 32 BEH ~~ BEH 3.142 1.058 2.969 0.003 1.067 5.216
#> 33 INT:PBC ~~ INT:PBC 0.957 0.080 11.954 0.000 0.800 1.113
#> 34 att1 ~~ att1 1.166 NA NA NA NA NA
#> 35 att1 ~~ att2 0.878 0.006 136.341 0.000 0.866 0.891
#> 36 att1 ~~ att3 0.788 0.007 120.564 0.000 0.775 0.801
#> 37 att1 ~~ att4 0.693 0.007 98.901 0.000 0.679 0.706
#> 38 att1 ~~ att5 0.885 0.007 134.726 0.000 0.872 0.898
#> 39 att2 ~~ att2 0.920 NA NA NA NA NA
#> 40 att2 ~~ att3 0.692 0.006 124.923 0.000 0.681 0.702
#> 41 att2 ~~ att4 0.609 0.006 105.895 0.000 0.598 0.620
#> 42 att2 ~~ att5 0.778 0.005 151.956 0.000 0.768 0.788
#> 43 att3 ~~ att3 0.781 NA NA NA NA NA
#> 44 att3 ~~ att4 0.547 0.007 80.756 0.000 0.534 0.561
#> 45 att3 ~~ att5 0.698 0.006 109.879 0.000 0.685 0.710
#> 46 att4 ~~ att4 0.645 NA NA NA NA NA
#> 47 att4 ~~ att5 0.616 0.006 100.146 0.000 0.604 0.628
#> 48 att5 ~~ att5 0.944 NA NA NA NA NA
#> 49 sn1 ~~ sn1 0.213 0.029 7.385 0.000 0.157 0.270
#> 50 sn2 ~~ sn2 0.128 0.022 5.908 0.000 0.085 0.170
#> 51 pbc1 ~~ pbc1 0.159 0.021 7.729 0.000 0.119 0.200
#> 52 pbc2 ~~ pbc2 0.136 0.020 6.768 0.000 0.097 0.175
#> 53 pbc3 ~~ pbc3 0.164 0.018 9.374 0.000 0.130 0.199
#> 54 int1 ~~ int1 0.171 0.015 11.052 0.000 0.141 0.202
#> 55 int2 ~~ int2 0.140 0.017 8.086 0.000 0.106 0.174
#> 56 int3 ~~ int3 0.174 0.016 11.015 0.000 0.143 0.206
#> 57 b1 ~~ b1 0.815 NA NA NA NA NA
#> 58 b1 ~~ b2 0.605 0.007 90.717 0.000 0.591 0.618
#> 59 b2 ~~ b2 0.716 NA NA NA NA NA