Transform parameter estimates from a fitted PLS-SEM model to observed- and latent-variable scales. Variables not selected through unstandardized remain on their standardized scales.

unstandardized_estimates(
  model,
  unstandardized = "all",
  se = c("delta", "none"),
  scale.uncertainty = FALSE,
  eps = 1e-04,
  zero.tol = 1e-10,
  rm.tmp.ov = TRUE,
  clean.tmp.ind = TRUE
)

# S4 method for class 'PlsModel'
unstandardized_estimates(
  model,
  unstandardized = "all",
  se = c("delta", "none"),
  scale.uncertainty = FALSE,
  eps = 1e-04,
  zero.tol = 1e-10,
  rm.tmp.ov = TRUE,
  clean.tmp.ind = TRUE
)

Arguments

model

A fitted PlsModel object.

unstandardized

Character vector naming variables to unstandardize, or one of "all", "ov", or "lv".

se

Character string selecting delta-method standard errors ("delta") or no standard errors ("none").

scale.uncertainty

Should scale uncertainty be included? defaults to FALSE.

eps

Positive numeric finite-difference step used for the delta-method Jacobian.

zero.tol

Non-negative numeric tolerance below which standard errors are returned as missing.

rm.tmp.ov

Logical; whether rows involving temporary observed variables should be removed from the returned parameter table.

clean.tmp.ind

Logical; whether rows involving temporary indicators should be cleaned from the returned parameter table.

Value

A PlsSemParTable containing transformed estimates and (when requested) delta-method standard errors. The transformed covariance matrix is stored in the "vcov" attribute.

Examples

tpb <- '
# Outer Model (Based on Hagger et al., 2007)
  ATT <~ att1 + att2 + att3 + att4 + att5
  SN =~ sn1 + sn2
  PBC =~ pbc1 + pbc2 + pbc3
  INT =~ int1 + int2 + int3
  BEH <~ b1 + b2

# Inner Model (Based on Steinmetz et al., 2011)
  INT ~ ATT + SN + PBC
  BEH ~ INT + PBC + INT:PBC
'

fit <- pls(tpb, modsem::TPB, bootstrap = TRUE, boot.R = 50)
unstandardized_estimates(fit)
#>        lhs op     rhs    est     se       z pvalue ci.lower ci.upper
#> 1      ATT <~    att1  1.000     NA      NA     NA       NA       NA
#> 2      ATT <~    att2  0.918  0.629   1.460  0.144   -0.314    2.150
#> 3      ATT <~    att3  1.085  0.596   1.820  0.069   -0.083    2.252
#> 4      ATT <~    att4  0.788  0.554   1.423  0.155   -0.297    1.873
#> 5      ATT <~    att5  1.272  0.666   1.911  0.056   -0.033    2.577
#> 6       SN =~     sn1  1.000     NA      NA     NA       NA       NA
#> 7       SN =~     sn2  0.921  0.022  42.265  0.000    0.878    0.964
#> 8      PBC =~    pbc1  1.000     NA      NA     NA       NA       NA
#> 9      PBC =~    pbc2  0.933  0.018  51.883  0.000    0.898    0.968
#> 10     PBC =~    pbc3  0.801  0.014  57.036  0.000    0.773    0.828
#> 11     INT =~    int1  1.000     NA      NA     NA       NA       NA
#> 12     INT =~    int2  0.936  0.017  54.918  0.000    0.903    0.970
#> 13     INT =~    int3  0.809  0.017  46.495  0.000    0.775    0.843
#> 14     BEH <~      b1  1.000     NA      NA     NA       NA       NA
#> 15     BEH <~      b2  1.476  0.377   3.914  0.000    0.737    2.215
#> 16     INT  ~     ATT  0.045  0.016   2.751  0.006    0.013    0.077
#> 17     INT  ~      SN  0.185  0.025   7.281  0.000    0.135    0.235
#> 18     INT  ~     PBC  0.224  0.023   9.619  0.000    0.178    0.270
#> 19     BEH  ~     PBC  0.558  0.084   6.639  0.000    0.393    0.722
#> 20     BEH  ~     INT  0.471  0.097   4.847  0.000    0.281    0.662
#> 21     BEH  ~ INT:PBC  0.506  0.086   5.873  0.000    0.337    0.675
#> 22     ATT ~~     ATT 19.621 13.909   1.411  0.158   -7.640   46.882
#> 23     ATT ~~      SN  2.682  0.930   2.883  0.004    0.859    4.505
#> 24     ATT ~~     PBC  2.921  1.035   2.823  0.005    0.893    4.949
#> 25     ATT ~~ INT:PBC  0.360  0.241   1.494  0.135   -0.112    0.831
#> 26      SN ~~      SN  0.953  0.044  21.743  0.000    0.867    1.039
#> 27      SN ~~     PBC  0.662  0.027  24.518  0.000    0.609    0.715
#> 28      SN ~~ INT:PBC  0.054  0.044   1.234  0.217   -0.032    0.141
#> 29     PBC ~~     PBC  0.948  0.034  27.542  0.000    0.881    1.016
#> 30     PBC ~~ INT:PBC  0.084  0.054   1.549  0.121   -0.022    0.191
#> 31     INT ~~     INT  0.484  0.022  21.643  0.000    0.440    0.527
#> 32     BEH ~~     BEH  3.142  0.958   3.280  0.001    1.264    5.019
#> 33 INT:PBC ~~ INT:PBC  0.957  0.071  13.567  0.000    0.818    1.095
#> 34    att1 ~~    att1  1.166     NA      NA     NA       NA       NA
#> 35    att1 ~~    att2  0.878  0.006 137.757  0.000    0.866    0.891
#> 36    att1 ~~    att3  0.788  0.007 106.523  0.000    0.773    0.802
#> 37    att1 ~~    att4  0.693  0.006 110.312  0.000    0.680    0.705
#> 38    att1 ~~    att5  0.885  0.008 113.978  0.000    0.869    0.900
#> 39    att2 ~~    att2  0.920     NA      NA     NA       NA       NA
#> 40    att2 ~~    att3  0.692  0.006 112.414  0.000    0.680    0.704
#> 41    att2 ~~    att4  0.609  0.006  98.821  0.000    0.597    0.621
#> 42    att2 ~~    att5  0.778  0.007 109.688  0.000    0.764    0.791
#> 43    att3 ~~    att3  0.781     NA      NA     NA       NA       NA
#> 44    att3 ~~    att4  0.547  0.007  83.076  0.000    0.534    0.560
#> 45    att3 ~~    att5  0.698  0.007  95.440  0.000    0.683    0.712
#> 46    att4 ~~    att4  0.645     NA      NA     NA       NA       NA
#> 47    att4 ~~    att5  0.616  0.006 103.617  0.000    0.604    0.627
#> 48    att5 ~~    att5  0.944     NA      NA     NA       NA       NA
#> 49     sn1 ~~     sn1  0.213  0.025   8.566  0.000    0.164    0.262
#> 50     sn2 ~~     sn2  0.128  0.019   6.563  0.000    0.090    0.166
#> 51    pbc1 ~~    pbc1  0.159  0.019   8.348  0.000    0.122    0.197
#> 52    pbc2 ~~    pbc2  0.136  0.022   6.280  0.000    0.093    0.178
#> 53    pbc3 ~~    pbc3  0.164  0.016  10.265  0.000    0.133    0.196
#> 54    int1 ~~    int1  0.171  0.018   9.776  0.000    0.137    0.205
#> 55    int2 ~~    int2  0.140  0.016   8.648  0.000    0.108    0.171
#> 56    int3 ~~    int3  0.174  0.016  11.199  0.000    0.144    0.205
#> 57      b1 ~~      b1  0.815     NA      NA     NA       NA       NA
#> 58      b1 ~~      b2  0.605  0.008  76.666  0.000    0.589    0.620
#> 59      b2 ~~      b2  0.716     NA      NA     NA       NA       NA